@@ -1,6 +1,8 @@
 import time
 
 import httpretty
+import pytest
+import requests
 
 from remoteconfig import config, RemoteConfig
 
@@ -34,3 +36,8 @@ class TestRemoteConfig(object):
     # Should update after cache duration
     config.read(config_url)
     assert updated_config_content == str(config)
+
+  def test_bad_url(self):
+    with pytest.raises(requests.ConnectionError):
+      config.read('http://bad-url-that-do-not-exist.bad/config.cfg')
+      config.might_get_here_or_not
